@@ -86,10 +86,10 @@ except ImportError:
 
 DEFAULTS = {
         'global_config':   {
-            'dbus'                  : False,
+            'dbus'                  : True,
             'focus'                 : 'click',
             'handle_size'           : -1,
-            'geometry_hinting'      : True,
+            'geometry_hinting'      : False,
             'window_state'          : 'normal',
             'borderless'            : False,
             'tab_position'          : 'top',
@@ -121,6 +121,8 @@ DEFAULTS = {
             'always_split_with_profile': False,
             'title_use_system_font' : True,
             'title_font'            : 'Sans 9',
+            'putty_paste_style'     : False,
+            'smart_copy'            : True,
         },
         'keybindings': {
             'zoom_in'          : '<Control>plus',
@@ -188,7 +190,9 @@ DEFAULTS = {
             'broadcast_all'    : '<Alt>a',
             'insert_number'    : '<Super>1',
             'insert_padded'    : '<Super>0',
-            'edit_window_title': '<Alt>t',
+            'edit_window_title': '<Control><Alt>w',
+            'edit_tab_title'   : '<Control><Alt>a',
+            'edit_terminal_title': '<Control><Alt>x',
             'layout_launcher'  : '<Alt>l',
             'next_profile'     : '',
             'previous_profile' : '', 
@@ -211,9 +215,10 @@ DEFAULTS = {
                 'color_scheme'          : 'grey_on_black',
                 'cursor_blink'          : True,
                 'cursor_shape'          : 'block',
-                'cursor_color'          : '#aaaaaa',
+                'cursor_color'          : '',
+                'cursor_color_fg'       : True,
                 'emulation'             : 'xterm',
-                'term'                  : 'xterm',
+                'term'                  : 'xterm-256color',
                 'colorterm'             : 'gnome-terminal',
                 'font'                  : 'Mono 10',
                 'foreground_color'      : '#aaaaaa',
@@ -221,7 +226,7 @@ DEFAULTS = {
                 'scrollbar_position'    : "right",
                 'scroll_background'     : True,
                 'scroll_on_keystroke'   : True,
-                'scroll_on_output'      : True,
+                'scroll_on_output'      : False,
                 'scrollback_lines'      : 500,
                 'scrollback_infinite'   : False,
                 'exit_action'           : 'close',
