@@ -4,6 +4,7 @@
 """paned.py - a base Paned container class and the vertical/horizontal
 variants"""
 
+import time
 import gobject
 import gtk
 
@@ -20,6 +21,8 @@ class Paned(Container):
     position = None
     maker = None
     ratio = 0.5
+    last_balance_time = 0
+    last_balance_args = None
 
     def __init__(self):
         """Class initialiser"""
@@ -142,17 +145,24 @@ class Paned(Container):
                 recurse_down=True
             else:
                 recurse_down=False
-            
-            # FIXME: These idle events are creating a lot of weird issues
-            for i in range(3):
-                while gtk.events_pending():
-                    gtk.main_iteration_do(False)
-                self.do_redistribute(recurse_up, recurse_down)
-            
+
+            self.last_balance_time = time.time()
+            self.last_balance_args = (recurse_up, recurse_down)
             return True
         else:
             return False
 
+    def on_button_release(self, widget, event):
+        """Handle button presses on a Pane"""
+        if event.button == 1:
+            if self.last_balance_time > (time.time() - 1):
+                # Dumb loop still needed, or some terms get squished on a Super rebalance
+                for i in range(3):
+                    while gtk.events_pending():
+                        gtk.main_iteration_do(False)
+                    self.do_redistribute(*self.last_balance_args)
+        return False
+
     def do_redistribute(self, recurse_up=False, recurse_down=False):
         """Evenly divide available space between sibling panes"""
         maker = Factory()
@@ -167,10 +177,7 @@ class Paned(Container):
             if maker.isinstance(grandfather, 'VPaned') or \
                maker.isinstance(grandfather, 'HPaned') :
                 grandfather.do_redistribute(recurse_up, recurse_down)
-        
-        gobject.idle_add(highest_ancestor._do_redistribute, recurse_up, recurse_down)
-        while gtk.events_pending():
-            gtk.main_iteration_do(False)
+
         gobject.idle_add(highest_ancestor._do_redistribute, recurse_up, recurse_down)
     
     def _do_redistribute(self, recurse_up=False, recurse_down=False):
@@ -433,6 +440,7 @@ class HPaned(Paned, gtk.HPaned):
         gtk.HPaned.__init__(self)
         self.register_signals(HPaned)
         self.cnxids.new(self, 'button-press-event', self.on_button_press)
+        self.cnxids.new(self, 'button-release-event', self.on_button_release)
 
     def get_length(self):
         return(self.allocation.width)
@@ -448,6 +456,7 @@ class VPaned(Paned, gtk.VPaned):
         gtk.VPaned.__init__(self)
         self.register_signals(VPaned)
         self.cnxids.new(self, 'button-press-event', self.on_button_press)
+        self.cnxids.new(self, 'button-release-event', self.on_button_release)
 
     def get_length(self):
         return(self.allocation.height)
